# Generated by Django 4.2.23 on 2026-05-30 21:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0011_extend_industry_activites'),
        ('markettracker', '0014_fix_trackeditem_unique_index_safe'),
    ]

    operations = [
        migrations.AddField(
            model_name='discordmessage',
            name='contract_alert_enabled',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='discordmessage',
            name='contract_restocked_alert_enabled',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='discordmessage',
            name='item_alert_enabled',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='discordmessage',
            name='item_restocked_alert_enabled',
            field=models.BooleanField(default=True),
        ),
    ]
